==> owlapi-api-3.4.10-sources.jar: org/semanticweb/owlapi/profiles/UseOfUnknownDatatype.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.profiles;

import org.semanticweb.owlapi.model.OWLAxiom;
import org.semanticweb.owlapi.model.OWLDatatype;
import org.semanticweb.owlapi.model.OWLOntology;

/** Use of an unknown datatype. That is, the datatype isn't in the OWL 2 datatype
 * map, the datatype IRI doesn't begin with the xsd: prefix, the datatype isn't
 * rdfs:Literal, and the datatype isn't defined with a DatatypeDefinition axiom
 * 
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group, Date: 03-Aug-2009 */
public class UseOfUnknownDatatype extends OWLProfileViolation implements
        OWL2ProfileViolation {
    private final OWLDatatype datatype;

    /** @param ontology
     *            ontology with violation
     * @param axiom
     *            axiom with violation
     * @param datatype
     *            unknown datatype */
    public UseOfUnknownDatatype(OWLOntology ontology, OWLAxiom axiom, OWLDatatype datatype) {
        super(ontology, axiom);
        this.datatype = datatype;
    }

    @Override
    public void accept(OWL2ProfileViolationVisitor visitor) {
        visitor.visit(this);
    }

    /** Gets the datatype that is invalid.
     * 
     * @return The invalid datatype */
    public OWLDatatype getDatatype() {
        return datatype;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("Use of unknown datatype: ");
        sb.append(datatype);
        sb.append(" [");
        sb.append(getAxiom());
        sb.append(" in ");
        sb.append(getOntologyID());
        sb.append("]");
        return sb.toString();
    }
}

==> owlapi-api-3.5.0-sources.jar: org/semanticweb/owlapi/profiles/UseOfUnknownDatatype.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.profiles;

import org.semanticweb.owlapi.model.OWLAxiom;
import org.semanticweb.owlapi.model.OWLDatatype;
import org.semanticweb.owlapi.model.OWLOntology;

/**
 * Use of an unknown datatype. That is, the datatype isn't in the OWL 2 datatype
 * map, the datatype IRI doesn't begin with the xsd: prefix, the datatype isn't
 * rdfs:Literal, and the datatype isn't defined with a DatatypeDefinition axiom
 * 
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group, Date: 03-Aug-2009
 */
public class UseOfUnknownDatatype extends OWLProfileViolation implements
        OWL2ProfileViolation {

    private final OWLDatatype datatype;

    /**
     * @param ontology
     *        ontology with violation
     * @param axiom
     *        axiom with violation
     * @param datatype
     *        unknown datatype
     */
    public UseOfUnknownDatatype(OWLOntology ontology, OWLAxiom axiom,
            OWLDatatype datatype) {
        super(ontology, axiom);
        this.datatype = datatype;
    }

    @Override
    public void accept(OWL2ProfileViolationVisitor visitor) {
        visitor.visit(this);
    }

    /**
     * Gets the datatype that is invalid.
     * 
     * @return The invalid datatype
     */
    public OWLDatatype getDatatype() {
        return datatype;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("Use of unknown datatype: ");
        sb.append(datatype);
        sb.append(" [");
        sb.append(getAxiom());
        sb.append(" in ");
        sb.append(getOntologyID());
        sb.append("]");
        return sb.toString();
    }
}
